@@ -78,9 +78,9 @@ void showHelp(const char *argv[], struct TDCMopts opts) {
 	printf("  -a : adjacent DICOMs (images from same series always in same folder) for faster conversion (n/y, default n)\n");
 	printf("  -b : BIDS sidecar (y/n/o [o=only: no NIfTI], default %c)\n", bool2Char(opts.isCreateBIDS));
 	printf("   -ba : anonymize BIDS (y/n, default %c)\n", bool2Char(opts.isAnonymizeBIDS));
-	printf("  -c : comment stored in NIfTI aux_file (provide up to 24 characters e.g. '-c first_visit')\n");
+	printf("  -c : comment stored in NIfTI aux_file (up to 24 characters e.g. '-c VIP', empty to anonymize e.g. 0020,4000 e.g. '-c \"\"')\n");
 	printf("  -d : directory search depth. Convert DICOMs in sub-folders of in_folder? (0..9, default %d)\n", opts.dirSearchDepth);
-#ifdef myEnableJNIfTI
+#ifdef myEnableJNIFTI
 	printf("  -e : export as NRRD (y) or MGH (o) or JSON/JNIfTI (j) or BJNIfTI (b) instead of NIfTI (y/n/o/j/b, default n)\n");
 #else
 	printf("  -e : export as NRRD (y) or MGH (o) instead of NIfTI (y/n/o/j/b, default n)\n");
@@ -104,6 +104,7 @@ void showHelp(const char *argv[], struct TDCMopts opts) {
 	printf("  -n : only convert this series CRC number - can be used up to %i times (default convert all)\n", MAX_NUM_SERIES);
 	printf("  -o : output directory (omit to save to input folder)\n");
 	printf("  -p : Philips precise float (not display) scaling (y/n, default y)\n");
+	printf("  -q : only search directory for DICOMs (y/l/n, default y) [y=show number of DICOMs found, l=additionally list DICOMs found, n=no]\n");
 	printf("  -r : rename instead of convert DICOMs (y/n, default n)\n");
 	printf("  -s : single file mode, do not convert other images in folder (y/n, default n)\n");
 //text notes replaced with BIDS: this function is deprecated
@@ -178,7 +179,7 @@ void showHelp(const char *argv[], struct TDCMopts opts) {
 } //showHelp()
 
 int invalidParam(int i, const char *argv[]) {
-	if (strchr("yYnNoOhHiIjJBb01234",argv[i][0]))
+	if (strchr("yYnNoOhHiIjlLJBb01234",argv[i][0]))
 		return 0;
 
 	//if (argv[i][0] != '-') return 0;
@@ -346,11 +347,19 @@ int main(int argc, const char *argv[]) {
 						opts.isAnonymizeBIDS = false;
 					else
 						opts.isAnonymizeBIDS = true;
+				} else if (argv[i][2] == 'i') { //"-bi M2022" provide BIDS subject ID
+					i++;
+					snprintf(opts.bidsSubject, kOptsStr-1, "%s", argv[i]);
+				} else if (argv[i][2] == 'v') { //"-bv 1222" provide BIDS subject visit
+					i++;
+					snprintf(opts.bidsSession, kOptsStr-1, "%s", argv[i]);
 				} else
 					printf("Error: Unknown command line argument: '%s'\n", argv[i]);
 			} else if ((argv[i][1] == 'c') && ((i + 1) < argc)) {
 				i++;
 				snprintf(opts.imageComments, 24, "%s", argv[i]);
+				if (strlen(opts.imageComments) == 0) //empty string is flag to anonymize DICOM image comments
+					snprintf(opts.imageComments, 24, "%s", "\t");
 			} else if ((argv[i][1] == 'd') && ((i + 1) < argc)) {
 				i++;
 				if ((argv[i][0] >= '0') && (argv[i][0] <= '9'))
@@ -367,7 +376,7 @@ int main(int argc, const char *argv[]) {
 					opts.saveFormat = kSaveFormatJNII;
 				if ((argv[i][0] == 'b') || (argv[i][0] == 'B') || (argv[i][0] == '4'))
 					opts.saveFormat = kSaveFormatBNII;
-				#ifndef myEnableJNIfTI
+				#ifndef myEnableJNIFTI
 				if ((opts.saveFormat == kSaveFormatJNII) || (opts.saveFormat == kSaveFormatBNII)) {
 					printf("Recompile for JNIfTI support.\n");
 					return EXIT_SUCCESS;
@@ -410,6 +419,25 @@ int main(int argc, const char *argv[]) {
 					opts.isTestx0021x105E = true;
 					printf("undocumented '-j y' compares GE slice timing from 0021,105E\n");
 				}
+			} else if ((!strcmp(argv[i], "--diffCyclingModeGE")) && ((i + 1) < argc)) {
+				// see issue 635
+				i++;
+				if (argv[i][0] == '0') {
+					opts.diffCyclingModeGE = 0;
+					printf("undocumented '--diffCyclingModeGE 0' cycling OFF\n");
+				}
+				else if (argv[i][0] == '1') {
+					opts.diffCyclingModeGE = 1;
+					printf("undocumented '--diffCyclingModeGE 1' cycling All-TR\n");
+				}
+				else if (argv[i][0] == '2') {
+					opts.diffCyclingModeGE = 2;
+					printf("undocumented '--diffCyclingModeGE 2' cycling 2-TR\n");
+				}
+				else if (argv[i][0] == '3') {
+					opts.diffCyclingModeGE = 3;
+					printf("undocumented '--diffCyclingModeGE 3' cycling 3-TR\n");
+				}				
 			} else if ((argv[i][1] == 'l') && ((i + 1) < argc)) {
 				i++;
 				if (invalidParam(i, argv))
@@ -452,6 +480,14 @@ int main(int argc, const char *argv[]) {
 					return 0;
 				if ((argv[i][0] == 'y') || (argv[i][0] == 'Y'))
 					opts.isRenameNotConvert = true;
+			} else if ((argv[i][1] == 'q') && ((i + 1) < argc)) {
+				i++;
+				if (invalidParam(i, argv))
+					return 0;
+				if ((argv[i][0] == 'y') || (argv[i][0] == 'Y'))
+					opts.onlySearchDirForDICOM = 1;
+				else if ((argv[i][0] == 'l') || (argv[i][0] == 'L'))
+					opts.onlySearchDirForDICOM = 2;
 			} else if ((argv[i][1] == 's') && ((i + 1) < argc)) {
 				i++;
 				if (invalidParam(i, argv))
@@ -605,11 +641,14 @@ int main(int argc, const char *argv[]) {
 		if (ret != EXIT_SUCCESS)
 			return ret;
 	}
+
+	if (opts.onlySearchDirForDICOM == 0) {
 #if !defined(_WIN64) && !defined(_WIN32)
-	printf("Conversion required %f seconds (%f for core code).\n", get_wall_time() - startWall, ((float)(clock() - start)) / CLOCKS_PER_SEC);
+		printf("Conversion required %f seconds (%f for core code).\n", get_wall_time() - startWall, ((float)(clock() - start)) / CLOCKS_PER_SEC);
 #else
-	printf("Conversion required %f seconds.\n", ((float)(clock() - start)) / CLOCKS_PER_SEC);
+		printf("Conversion required %f seconds.\n", ((float)(clock() - start)) / CLOCKS_PER_SEC);
 #endif
+	}
 	//if (isSaveIni) //we now save defaults earlier, in case of early termination.
 	//	saveIniFile(opts);
 	return EXIT_SUCCESS;
