@@ -4,6 +4,38 @@
 #ifndef MRIpro_nii_batch_h
 #define MRIpro_nii_batch_h
 
+#ifdef USING_DCM2NIIXFSWRAPPER
+#include "nifti1.h"
+#include "nii_dicom.h"
+#include <vector>
+
+struct MRIFSSTRUCT
+{
+  struct nifti_1_header hdr0;
+
+  size_t         imgsz;
+  unsigned char *imgM;
+
+  struct TDICOMdata tdicomData;
+  char namePostFixes[256];
+  char *dicomfile;
+
+  int nDcm;
+  char **dicomlst;
+
+  struct TDTI *tdti;
+  int numDti;
+};
+
+MRIFSSTRUCT* nii_getMrifsStruct();
+void nii_clrMrifsStruct();
+
+std::vector<MRIFSSTRUCT>* nii_getMrifsStructVector();
+void nii_clrMrifsStructVector();
+
+void dcmListDump(int nConvert, struct TDCMsort dcmSort[], struct TDICOMdata dcmList[], struct TSearchList *nameList, struct TDCMopts opts);
+#endif
+
 #ifdef  __cplusplus
 extern "C" {
 #endif
@@ -23,22 +55,6 @@ extern "C" {
     };
 #endif
 
-typedef struct 
-{
-    struct nifti_1_header hdr0;
-
-    size_t         imgsz;
-    unsigned char *imgM;
-
-    struct TDICOMdata tdicomData;
-
-    struct TDTI *tdti;
-    int numDti;
-} MRIFSSTRUCT;
-
-MRIFSSTRUCT* nii_getMrifsStruct();
-void nii_clrMrifsStruct();
-
 #define kNAME_CONFLICT_SKIP 0 //0 = write nothing for a file that exists with desired name
 #define kNAME_CONFLICT_OVERWRITE 1 //1 = overwrite existing file with same name
 #define kNAME_CONFLICT_ADD_SUFFIX 2 //default 2 = write with new suffix as a new file
@@ -54,15 +70,17 @@ void nii_clrMrifsStruct();
 #define kSaveFormatBNII 4
 
 #define MAX_NUM_SERIES 16
+#define kOptsStr 512
 
     struct TDCMopts {
-        bool isIgnoreTriggerTimes, isTestx0021x105E, isAddNamePostFixes, isSaveNativeEndian, isOneDirAtATime, isRenameNotConvert, isSave3D, isGz, isPipedGz, isFlipY,  isCreateBIDS, isSortDTIbyBVal, isAnonymizeBIDS, isOnlyBIDS, isCreateText, isForceOnsetTimes,isIgnoreDerivedAnd2D, isPhilipsFloatNotDisplayScaling, isTiltCorrect, isRGBplanar, isOnlySingleFile, isForceStackDCE, isIgnoreSeriesInstanceUID, isRotate3DAcq, isCrop;
-        int saveFormat, isMaximize16BitRange, isForceStackSameSeries, nameConflictBehavior, isVerbose, isProgress, compressFlag, dirSearchDepth, gzLevel; //support for compressed data 0=none,
-        char filename[512], outdir[512], indir[512], pigzname[512], optsname[512], indirParent[512], imageComments[24];
+        bool isDumpNotConvert;
+        bool isIgnoreTriggerTimes, isTestx0021x105E, isAddNamePostFixes, isSaveNativeEndian, isOneDirAtATime, isRenameNotConvert, isSave3D, isGz, isPipedGz, isFlipY,  isCreateBIDS, isSortDTIbyBVal, isAnonymizeBIDS, isOnlyBIDS, isCreateText, isForceOnsetTimes,isIgnoreDerivedAnd2D, isPhilipsFloatNotDisplayScaling, isTiltCorrect, isRGBplanar, isOnlySingleFile, isForceStackDCE, isIgnoreSeriesInstanceUID, isRotate3DAcq, isCrop, isGuessBidsFilename;
+        int saveFormat, isMaximize16BitRange, isForceStackSameSeries, nameConflictBehavior, isVerbose, isProgress, compressFlag, dirSearchDepth, onlySearchDirForDICOM, gzLevel, diffCyclingModeGE; //support for compressed data 0=none,
+        char filename[kOptsStr], outdir[kOptsStr], indir[kOptsStr], pigzname[kOptsStr], optsname[kOptsStr], indirParent[kOptsStr], imageComments[24], bidsSubject[kOptsStr], bidsSession[kOptsStr];
         double seriesNumber[MAX_NUM_SERIES]; //requires double must store -1 (report but do not convert) as well as seriesUidCrc (uint32)
         long numSeries;
 #ifdef USING_R
-        bool isScanOnly;
+        bool isScanOnly, isImageInMemory;
         void *imageList;
         std::vector<TDicomSeries> series;
 
@@ -77,7 +95,7 @@ void nii_clrMrifsStruct();
     void readIniFile (struct TDCMopts *opts, const char * argv[]);
     int nii_saveNIIx(char * niiFilename, struct nifti_1_header hdr, unsigned char* im, struct TDCMopts opts);
     int nii_loadDir(struct TDCMopts *opts);
-    int nii_loadDirCore(char *indir, struct TDCMopts* opts);
+  int nii_loadDirCore(char *indir, struct TDCMopts* opts);
     void nii_SaveBIDS(char pathoutname[], struct TDICOMdata d, struct TDCMopts opts, struct nifti_1_header *h, const char * filename);
     int nii_createFilename(struct TDICOMdata dcm, char * niiFilename, struct TDCMopts opts);
     void  nii_createDummyFilename(char * niiFilename, struct TDCMopts opts);
